% ConfigureSimParams.m (script)
%
% Set some simulation parameters for the model PendTwoMod.mdl
%
% --
% Supplementary material to:
% Sebastian Trimpe, "Stability Analysis of Distributed Event-Based State
% Estimation", IEEE Conference on Decision and Control (CDC), 2014.
%
% Copyright:
% Sebastian Trimpe
% Max-Planck-Institute for Intelligent Systems
% Autonomous Motion Department
% strimpe(at)tuebingen.mpg.de
%

% Revision history
% [21.03.14]   preliminary version, published with initial submission
% [14.09.14]   Generate random numbers in Matlab, then use in Simulink as
%               input from .mat-file

%% User configuration
% Seed for random number generation

simParam_seed = 123;        % Reproduce results (simulations shown in paper)
%simParam_seed = 'shuffle';   % Random initialization



%% Parameters
simParam_time = 100;                    % simulation time
simParam_delta = [0.005 0.005 0.005];   % triggering thresholds
simParam_syncAvg = 1;                   % synchronous averaging: 0 or 1 (off or on)
simParam_syncAvgPeriod = 200;           % sync averaging period K
simParam_pckDrop = 1;                   % simulate packet drops? 0 or 1 (off or on)
simParam_pckDropProb = 0.05;            % packet drop probability
simParam_disturbance = 1;               % simulate impulsive disturbance on input u1? 0 or 1 (off or on)
simParam_gyroVar = 1.7546e-05;          % measurement noise variance (from experimental data on Balancing Cube)

% Initial conditions
p_pend2M.ICAngleUpperMod = 0;
p_pend2M.ICAngleLowerMod = 0;
p_pend2M.ICAnglePend = 0;


%% Generate random numbers for simulation
% Generate numbers in Matlab, save in *.mat-file, read from Simulink
% simulation.
GenerateRandomNumbers(simParam_seed,simParam_time,simParam_gyroVar);
